%global debug_package %{nil}

%if 0%{?rhel}
# Currently python3_pkgversion is set to 34 when EPEL is enabled.  However, not
# all our dependencies have python34-* subpackages yet.  Once they do, this
# definition override should be removed.
%global python3_pkgversion %{nil}
%endif

Name:           docker-compose
Version:        1.17.1
Release:        1%{?dist}
Summary:        Multi-container orchestration for Docker

License:        ASL 2.0
URL:            https://github.com/docker/compose
Source0:        https://files.pythonhosted.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz

# Remove dependency version constraints not relevant in Fedora/EPEL
Patch0:         remove-requires-upper-bound.patch

# https://github.com/docker/compose/issues/4884
Patch1:         allow-older-requests.patch

# Upstream uses environment markers to conditionally apply some dependencies.
# Environment markers were first added in setuptools 20.6.8.
Patch2:         allow-older-setuptools.patch

# docker-compose is compatible with fig and is a simple rename.
# Currently it only prints deprecation warnings for changed functionality.
Provides:       fig = %{version}-%{release}
# Last fig EVR was 1.0.1-2
Obsoletes:      fig <= 1.0.1-3

BuildRequires:  python%{?python3_pkgversion}-devel
BuildRequires:  python%{?python3_pkgversion}-setuptools

Requires:       python%{?python3_pkgversion}-setuptools
Requires:       python%{?python3_pkgversion}-cached_property >= 1.2.0
Requires:       python%{?python3_pkgversion}-docopt >= 0.6.1
Requires:       python%{?python3_pkgversion}-yaml >= 3.10
Requires:       python%{?python3_pkgversion}-requests >= 2.6.0
Requires:       python%{?python3_pkgversion}-texttable >= 0.9.0
Requires:       python%{?python3_pkgversion}-websocket-client >= 0.32.0
Requires:       python%{?python3_pkgversion}-docker >= 2.5.1
Requires:       python%{?python3_pkgversion}-dockerpty >= 0.4.1
Requires:       python%{?python3_pkgversion}-six >= 1.3.0
Requires:       python%{?python3_pkgversion}-jsonschema >= 2.5.1
Requires:       python%{?python3_pkgversion}-pysocks >= 1.5.6
%if 0%{?python3_version_nodots} < 34
Requires:       python%{?python3_pkgversion}-enum34 >= 1.0.4
%endif
%if 0%{?python3_version_nodots} < 35
Requires:       python%{?python3_pkgversion}-backports-ssl_match_hostname >= 3.5
%endif
%if 0%{?python3_version_nodots} < 33
Requires:       python%{?python3_pkgversion}-ipaddress >= 1.0.16
%endif

BuildArch:      noarch

%description
Compose is a tool for defining and running multi-container Docker
applications. With Compose, you use a Compose file to configure your
application's services. Then, using a single command, you create and
start all the services from your configuration.

Compose is great for development, testing, and staging environments,
as well as CI workflows.

Using Compose is basically a three-step process.

1. Define your app's environment with a Dockerfile so it can be
   reproduced anywhere.
2. Define the services that make up your app in docker-compose.yml so
   they can be run together in an isolated environment:
3. Lastly, run docker-compose up and Compose will start and run your
   entire app.

%prep
%autosetup -p 1

# Upstream uses an underscore here
rm -r docker_compose.egg-info

%build
%if 0%{?python3_pkgversion}
%py3_build
%else
%py2_build
%endif

%install
%if 0%{?python3_pkgversion}
%py3_install
%else
%py2_install
%endif
install -D -p -m 644 contrib/completion/bash/docker-compose %{buildroot}%{_datadir}/bash-completion/completions/docker-compose
install -D -p -m 644 contrib/completion/zsh/_docker-compose %{buildroot}%{_datadir}/zsh/site-functions/_docker-compose
install -D -p -m 644 contrib/completion/fish/docker-compose.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/docker-compose.fish

%files
%doc CHANGELOG.md README.rst
%license LICENSE
%{_bindir}/%{name}
%if 0%{?python3_pkgversion}
%{python3_sitelib}/*
%else
%{python2_sitelib}/*
%endif
%{_datadir}/bash-completion
%{_datadir}/zsh
%{_datadir}/fish

%changelog
* Thu Nov  9 2017 Michael Hampton <error@ioerror.us> - 1.17.1-1
- Update to 1.17.1 (#1511455)

* Thu Nov  2 2017 Michael Hampton <error@ioerror.us> - 1.17.0-1
- Update to 1.17.0 (#1504337)

* Sun Sep 10 2017 Carl George <carl@george.computer> - 1.16.1-2
- Align dependencies with upstream
- RHEL compatibility
- Add bash, zsh, and fish completions

* Sat Sep  2 2017 Michael Hampton <error@ioerror.us> - 1.16.1-1
- Update to 1.16.1 (#1483776)

* Fri Jul 28 2017 Michael Hampton <error@ioerror.us> - 1.15.0-1
- Update to 1.15.0 (#1471093)
- Explicit python3-docker requirement
- New upstream requirements python3-pysocks, python3-certifi, python3-idna

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Jun 20 2017 Michael Hampton <error@ioerror.us> - 1.14.0-1
- Update to upstream 1.14.0

* Mon May  8 2017 Michael Hampton <error@ioerror.us> - 1.13.0-1
- Update to upstream 1.13.0

* Fri Apr  7 2017 Michael Hampton <error@ioerror.us> - 1.12.0-1
- Update to upstream 1.12.0

* Thu Mar  2 2017 Michael Hampton <error@ioerror.us> - 1.11.2-1
- Update to upstream 1.11.2

* Tue Feb 28 2017 Michael Hampton <error@ioerror.us> - 1.11.1-3
- Remove requirements upper bound from setup.py; BZ#1426145
- Added new dependency python3-colorama

* Fri Feb 17 2017 Michael Hampton <error@ioerror.us> - 1.11.1-2
- python-docker-py package name changed to python-docker; BZ#1422198

* Fri Feb 10 2017 Michael Hampton <error@ioerror.us> - 1.11.1-1
- Update to upstream 1.11.1

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb  3 2017 Michael Hampton <error@ioerror.us> - 1.10.1-1
- Update to upstream 1.10.1

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.9.0-3
- Rebuild for Python 3.6

* Mon Nov 21 2016 Michael Hampton <error@ioerror.us> - 1.9.0-2
- BZ#1396852

* Sat Nov 19 2016 Michael Hampton <error@ioerror.us> - 1.9.0-1
- Update to upstream 1.9.0

* Fri Sep 23 2016 Michael Hampton <error@ioerror.us> - 1.8.1-1
- Update to upstream 1.8.1

* Sat Sep 10 2016 Michael Hampton <error@ioerror.us> - 1.8.0-2
- Port to Python 3, BZ#1374656

* Thu Jul 28 2016 Michael Hampton <error@ioerror.us> - 1.8.0-1
- Update to upstream 1.8.0

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu May 05 2016 Michael Hampton <error@ioerror.us> - 1.7.1-1
- Update to upstream 1.7.1
- Updated package description from upstream

* Thu Apr 14 2016 Michael Hampton <error@ioerror.us> - 1.7.0-1
- Update to upstream 1.7.0

* Fri Feb 05 2016 Michael Hampton <error@ioerror.us> - 1.6.0-1
- Update to upstream 1.6.0

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 12 2016 Michael Hampton <error@ioerror.us> - 1.5.2-4
- Added missing dependency python-enum34

* Mon Jan 11 2016 Michael Hampton <error@ioerror.us> - 1.5.2-3
- Added missing dependency python-jsonschema

* Wed Dec 30 2015 Michael Hampton <error@ioerror.us> - 1.5.2-2
- Updated locations of docs

* Wed Dec 30 2015 Michael Hampton <error@ioerror.us> - 1.5.2-1
- Update to upstream 1.5.2

* Wed Sep 23 2015 Michael Hampton <error@ioerror.us> - 1.4.2-1
- Fixes a regression in the 1.4.1 release that would cause
  docker-compose up without the -d option to exit immediately.

* Wed Sep 16 2015 Michael Hampton <error@ioerror.us> - 1.4.1-1
- Update to upstream 1.4.1

* Wed Aug 12 2015 Michael Hampton <error@ioerror.us> - 1.4.0-1
- Update to upstream 1.4.0
- Update Summary to match upstream summary

* Sat May 16 2015 Michael Hampton <error@ioerror.us> - 1.2.0-3
- Update Obsoletes EVR per packaging guidelines BZ#1213111

* Sun Apr 19 2015 Michael Hampton <error@ioerror.us> - 1.2.0-2
- Update location of LICENSE file

* Sat Apr 18 2015 Michael Hampton <error@ioerror.us> - 1.2.0-1
- Update to 1.2.0
- Added new doc SWARM.md
- Removed docker package requires as it is not required to build or run the
  package, only to run tests, which we can't do anyway
- Removed commented code relating to running tests, which we can't do anyway
- Made package noarch as docker-io is no longer required

* Mon Mar 23 2015 Michael Hampton <error@ioerror.us> - 1.1.0-1
- Update to 1.1.0 including upstream name change
- Requires python-dockerpty
- Requires python-docker-py >= 0.7.1-3 BZ#1197300

* Tue Mar 17 2015 Matej Stuchlik <mstuchli@redhat.com> - 1.0.1-2
- Completely remove version specs from setup.py

* Tue Mar 17 2015 Matej Stuchlik <mstuchli@redhat.com> - 1.0.1-1
- Update to 1.0.1

* Wed Dec 03 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-5
- Remove upper bound from setup.py requires

* Wed Nov 12 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-4
- Add python-setuptools to requires

* Thu Oct 23 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-3
- Relax strict version requirements on websocket-client (#1155510)

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-2
- Update Requires

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 1.0.0-1
- Update to 1.0.0
- Droped the two patches

* Tue Oct 21 2014 Matej Stuchlik <mstuchli@redhat.com> - 0.5.2-2
- Explicitly disable debuginfo subpackage (#1154780)
- Add python-docker-py to Requires (#1154874)

* Thu Oct 09 2014 Matej Stuchlik <mstuchli@redhat.com> - 0.5.2-1
- Initial spec based on rhbz#1129889
